@@ -630,7 +630,13 @@ getCols <- function (data, cols)
 
 # allows negative indexing subset(dat,,-c(3:5))
 getRows <- function (data, rows, site.pattern = TRUE) 
-{              
+{   
+    if(!site.pattern & all(rows>0)){
+        weight = tabulate(rows)
+        ind = which(weight>0)
+        rows = rows[ind]
+        weight = weight[ind]
+    } 
     for (i in 1:length(data)){ 
         if(is.matrix(data[[i]]))data[[i]] = data[[i]][rows,]
         else data[[i]] = data[[i]][rows]
@@ -638,7 +644,10 @@ getRows <- function (data, rows, site.pattern = TRUE)
 #    if(site.pattern) attr(data, "weight") = attr(data, "weight")[rows]
 #    else attr(data, "weight") = rep(1, length(rows))
     attr(data, "weight") = attr(data, "weight")[rows]
-    if(!site.pattern) attr(data, "weight")[] = 1
+    if(!site.pattern){
+        if(all(rows>0))attr(data, "weight") = weight 
+        else attr(data, "weight")[] = 1
+    }    
     attr(data, "nr") = length(attr(data, "weight"))
     attr(data, "index") = NULL
     data
@@ -650,7 +659,10 @@ subset.phyDat <- function (x, subset, select, site.pattern = TRUE,...)
      
     if (!missing(subset)) x <- getCols(x, subset)
     if (!missing(select)){
-         if(!site.pattern)select <- attr(x, "index")[select] 
+         if(!site.pattern){
+             if(is.data.frame(attr(x, "index"))) select <- attr(x, "index")[select,1]
+             else select <- attr(x, "index")[select]
+         }     
          if(any(is.na(select))) return(NULL) 
          x <- getRows(x, select, site.pattern=site.pattern)
     }    
